package ttt.gui;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

// Factory pattern (implementation)
public final class GuiFactory {
    // private constructor so that factory cannot be instantiated
    private GuiFactory() {}
    
    public static JButton createButton(String text, Container panel,
            ActionListener listener) {
        // if (text == null)!!
        JButton button = new JButton(text);
        button.addActionListener(listener);
        
        panel.add(button);
        return button;
    }
    
    public static JButton createButton(Container panel, Action action) {
        // if (text == null)!!
        JButton button = new JButton(action);
        panel.add(button);
        return button;
    }
    
    public static JMenu createMenu(String text, JMenuBar bar) {
        JMenu menu = new JMenu(text);
        char firstLetter = text.charAt(0);
        menu.setMnemonic(firstLetter);
        bar.add(menu);
        return menu;
    }
    
    public static JMenuItem createMenuItem(String text, JMenu menu,
            ActionListener listener) {
        JMenuItem item = new JMenuItem(text);
        char firstLetter = text.charAt(0);
        item.setMnemonic(firstLetter);
        item.addActionListener(listener);
        menu.add(item);
        return item;
    }
    
    public static JMenuItem createMenuItem(JMenu menu, Action action) {
        JMenuItem item = new JMenuItem(action);
        // char firstLetter = ((String)action.getValue(Action.NAME)).charAt(0);
        // item.setMnemonic(firstLetter);
        menu.add(item);
        return item;
    }
    
    public static JMenuItem createMenuItemWithHotkey(String text, JMenu menu,
            ActionListener listener) {
        JMenuItem item = createMenuItem(text, menu, listener);
        char firstLetter = text.charAt(0);
        KeyStroke hotkey = KeyStroke.getKeyStroke(firstLetter,
                KeyEvent.CTRL_MASK);
        item.setAccelerator(hotkey);
        return item;
    }
}
